"""A setuptools based setup module.

See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

# "import" __version__ (trick out of https://github.com/spatialaudio/nbsphinx/blob/master/setup.py)
for line in open('cbsodata.py'):
    if line.startswith('__version__'):
        exec(line)
        break

setup(
    name='cbsodata',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version=__version__,

    description='Statistics Netherlands opendata API client for Python',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/J535D165/cbsodata',

    # Author details
    author='Jonathan de Bruin',
    author_email='jonathandebruinhome@gmail.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5'
    ],

    # What does your project relate to?
    keywords='cbs statistics odata netherlands dutch',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    # packages=['cbsodata'],

    install_requires=['requests'],

    py_modules=['cbsodata'],

    tests_require=[
        'nose',
        'nose-parameterized'
    ],

)
